package com.docus.server.collection.controller;

import com.docus.core.util.Func;
import com.docus.infrastructure.core.exception.BaseException;
import com.docus.infrastructure.web.api.CommonResult;
import com.docus.infrastructure.web.api.ResultCode;
import com.docus.server.collection.converter.FirstPageCheckoutConverter;
import com.docus.server.collection.dto.FirstPageCheckoutInDTO;
import com.docus.server.collection.dto.FirstPageCheckoutRequest;
import com.docus.server.collection.feign.service.MedicalrecordService;
import com.docus.server.collection.service.MzZyHisService;
import com.docus.server.collection.util.PersistRequestUtil;
import com.docus.server.collection.validator.RequestValidator;
import com.docus.server.collection.validator.ValidateResult;
import com.docus.server.collection.validator.impl.FirstPageCheckoutRequestValidator;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiOperation;
import lombok.extern.slf4j.Slf4j;
import org.springframework.web.bind.annotation.*;

import javax.annotation.Resource;
import javax.servlet.http.HttpServletRequest;

@Api("梅州中西HIS相关接口")
@Slf4j
@RestController
@RequestMapping("/his")
public class MzZyHisController {
    @Resource
    private MzZyHisService mzZyHisService;

    @Resource
    private MedicalrecordService medicalrecordService;

    @ApiOperation("首页签出")
    @PostMapping("/firstPageCheckout")
    public CommonResult<String> firstPageCheckout(@RequestBody FirstPageCheckoutRequest firstPageCheckoutRequest, HttpServletRequest servletRequest) {
        String method = servletRequest.getRequestURI().replace("/", "_").replace("\\", "_");
        log.info("首页签出接口参数：{}", Func.toJson(firstPageCheckoutRequest));
        // 验证数据
        RequestValidator validator = new FirstPageCheckoutRequestValidator(firstPageCheckoutRequest);
        ValidateResult validateResult = validator.validate();
        if (validateResult.getResultCode() == ResultCode.FAILED) {
            return CommonResult.failed(validateResult.getMsg());
        }
        // 转换数据，业务处理
        FirstPageCheckoutConverter converter = new FirstPageCheckoutConverter(firstPageCheckoutRequest);
        FirstPageCheckoutInDTO checkoutInDTO = converter.req2dto();
        try {
            mzZyHisService.firstPageCheckout(checkoutInDTO);
            return CommonResult.success("操作成功！");
        } catch (BaseException ex) {
            log.error(ex.getMessage(), ex);
            return CommonResult.failed(ex.getMessage());
        } catch (Exception ex) {
            log.error(ex.getMessage(), ex);
            PersistRequestUtil.persistRequest(method,Func.toJson(firstPageCheckoutRequest));
            return CommonResult.failed("系统出错啦，请稍后再试！");
        }
    }
    @ApiOperation("测试")
    @GetMapping("/test")
    public CommonResult<String> test(@RequestParam("pid") String pid) {
        medicalrecordService.signOutOrBackRepair(pid);
        return CommonResult.success("ok");
    }
}
